Struct Any
pub struct Any(FloatTypes);Expand description
Strategies which produce floating-point values from particular
classes. See the various Any-typed constants in this module.
Note that this usage is fairly advanced and primarily useful to
implementors of algorithms that need to handle wild values in a
particular way. For testing things like graphics processing or game
physics, simply using ranges (e.g., -1.0..2.0) will often be more
practical.
Any can be OR’ed to combine multiple classes. For example,
POSITIVE | INFINITE will generate arbitrary positive, non-NaN
floats, including positive infinity (but not negative infinity, of
course).
If neither POSITIVE nor NEGATIVE has been OR’ed into an Any
but a type to be generated requires a sign, POSITIVE is assumed.
If no classes are OR’ed into an Any (i.e., only POSITIVE and/or
NEGATIVE are given), NORMAL is assumed.
The various float classes are assigned fixed weights for generation which are believed to be reasonable for most applications. Roughly:
-
If
POSITIVE | NEGATIVE, the sign is evenly distributed between both options. -
Classes are weighted as follows, in descending order:
NORMAL>ZERO>SUBNORMAL>INFINITE>QUIET_NAN=SIGNALING_NAN.
Tuple Fields
0: FloatTypesTrait Implementations
impl BitOrAssign for Any
impl BitOrAssign for Any
fn bitor_assign(&mut self, rhs: Any)
fn bitor_assign(&mut self, rhs: Any)
|= operation. Read moreimpl Strategy for Any
impl Strategy for Any
type Tree = BinarySearch
type Tree = BinarySearch
Strategy.type Value = f64
type Value = f64
fn new_tree(
&self,
runner: &mut TestRunner,
) -> Result<<Any as Strategy>::Tree, Reason>
fn new_tree( &self, runner: &mut TestRunner, ) -> Result<<Any as Strategy>::Tree, Reason>
fn prop_map<O, F>(self, fun: F) -> Map<Self, F>
fn prop_map<O, F>(self, fun: F) -> Map<Self, F>
fun. Read morefn prop_map_into<O>(self) -> MapInto<Self, O>
fn prop_map_into<O>(self) -> MapInto<Self, O>
fn prop_perturb<O, F>(self, fun: F) -> Perturb<Self, F>
fn prop_perturb<O, F>(self, fun: F) -> Perturb<Self, F>
fun, which is additionally given a random number generator. Read morefn prop_flat_map<S, F>(self, fun: F) -> Flatten<Map<Self, F>>
fn prop_flat_map<S, F>(self, fun: F) -> Flatten<Map<Self, F>>
fn prop_ind_flat_map<S, F>(self, fun: F) -> IndFlatten<Map<Self, F>>
fn prop_ind_flat_map<S, F>(self, fun: F) -> IndFlatten<Map<Self, F>>
fn prop_ind_flat_map2<S, F>(self, fun: F) -> IndFlattenMap<Self, F>
fn prop_ind_flat_map2<S, F>(self, fun: F) -> IndFlattenMap<Self, F>
prop_ind_flat_map(), but produces 2-tuples with the input
generated from self in slot 0 and the derived strategy in slot 1. Read morefn prop_filter<R, F>(self, whence: R, fun: F) -> Filter<Self, F>
fn prop_filter<R, F>(self, whence: R, fun: F) -> Filter<Self, F>
fun. Read morefn prop_filter_map<F, O>(
self,
whence: impl Into<Reason>,
fun: F,
) -> FilterMap<Self, F>
fn prop_filter_map<F, O>( self, whence: impl Into<Reason>, fun: F, ) -> FilterMap<Self, F>
fun
returns Some(value) and rejects those where fun returns None. Read morefn prop_union(self, other: Self) -> Union<Self>where
Self: Sized,
fn prop_union(self, other: Self) -> Union<Self>where
Self: Sized,
fn prop_recursive<R, F>(
self,
depth: u32,
desired_size: u32,
expected_branch_size: u32,
recurse: F,
) -> Recursive<Self::Value, F>
fn prop_recursive<R, F>( self, depth: u32, desired_size: u32, expected_branch_size: u32, recurse: F, ) -> Recursive<Self::Value, F>
self items as leaves. Read morefn prop_shuffle(self) -> Shuffle<Self>
fn prop_shuffle(self) -> Shuffle<Self>
fn boxed(self) -> BoxedStrategy<Self::Value>where
Self: Sized + 'static,
fn boxed(self) -> BoxedStrategy<Self::Value>where
Self: Sized + 'static,
Strategy so it can be passed around as a
simple trait object. Read morefn sboxed(self) -> SBoxedStrategy<Self::Value>
fn sboxed(self) -> SBoxedStrategy<Self::Value>
Strategy so it can be passed around as a
simple trait object. Read moreimpl Copy for Any